cheesecake.logger.File

Package cheesecake :: Module logger :: Class File |
[hide private]
[frames] | no frames]

## Class File
source code

    object --+
             |
            File

Known Subclasses:
  Path

Instance Methods | [hide private]
| __init__(self, f) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| __call__(self, msg)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, f) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __call__(self, msg) (Call operator) | source code